@@ -4,7 +4,7 @@
 #
 # (C) 2005-2006 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: IP4.pm 14 2006-11-04 15:30:34Z Julian Mehnle $
+# $Id: IP4.pm 22 2006-11-15 03:31:28Z Julian Mehnle $
 #
 ##############################################################################
 
@@ -25,7 +25,7 @@ use constant TRUE   => (0 == 0);
 use constant FALSE  => not TRUE;
 
 use constant name           => 'ip4';
-use constant name_pattern   => qr/${\name}/;
+use constant name_pattern   => qr/${\name}/i;
 
 =head1 DESCRIPTION
 
@@ -112,7 +112,7 @@ sub parse_params {
 
 sub params {
     my ($self) = @_;
-    my $params = $self->{ip_network}->addr;
+    my $params = ':' . $self->{ip_network}->addr;
     $params .= '/' . $self->{ip_network}->masklen
         if $self->{ip_network}->masklen != $self->default_ipv4_prefix_length;
     return $params;
@@ -141,7 +141,11 @@ request's IP address, or B<false> otherwise.  See RFC 4408, 5.6, for details.
 
 sub match {
     my ($self, $server, $request) = @_;
-    return $self->ip_network->contains($request->ip_address);
+    my $ip_network_v6 =
+        $self->ip_network->version == 4 ?
+            Mail::SPF::Util->ipv4_address_to_ipv6($self->ip_network)
+        :   $self->ip_network;
+    return $ip_network_v6->contains($request->ip_address_v6);
 }
 
 =back
@@ -150,7 +154,7 @@ sub match {
 
 L<Mail::SPF>, L<Mail::SPF::Record>, L<Mail::SPF::Term>, L<Mail::SPF::Mech>
 
-L<http://www.ietf.org/rfc/rfc4408.txt|"RFC 4408">
+L<RFC 4408|http://www.ietf.org/rfc/rfc4408.txt>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
