@@ -4,7 +4,7 @@
 #
 # (C) 2005-2006 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: PTR.pm 14 2006-11-04 15:30:34Z Julian Mehnle $
+# $Id: PTR.pm 22 2006-11-15 03:31:28Z Julian Mehnle $
 #
 ##############################################################################
 
@@ -29,7 +29,7 @@ use constant TRUE   => (0 == 0);
 use constant FALSE  => not TRUE;
 
 use constant name           => 'ptr';
-use constant name_pattern   => qr/${\name}/;
+use constant name_pattern   => qr/${\name}/i;
 
 =head1 DESCRIPTION
 
@@ -112,7 +112,7 @@ sub parse_params {
 
 sub params {
     my ($self) = @_;
-    return $self->{domain_spec};
+    return defined($self->{domain_spec}) ? ':' . $self->{domain_spec} : undef;
 }
 
 =item B<stringify>
@@ -141,6 +141,7 @@ algorithm.
 
 sub match {
     my ($self, $server, $request) = @_;
+    $server->count_dns_interactive_term($request);
     return
         Mail::SPF::Util->valid_domain_for_ip_address(
             $server, $request->ip_address, $self->domain($server, $request))
@@ -153,7 +154,7 @@ sub match {
 
 L<Mail::SPF>, L<Mail::SPF::Record>, L<Mail::SPF::Term>, L<Mail::SPF::Mech>
 
-L<http://www.ietf.org/rfc/rfc4408.txt|"RFC 4408">
+L<RFC 4408|http://www.ietf.org/rfc/rfc4408.txt>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
