@@ -4,7 +4,7 @@
 #
 # (C) 2005-2006 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: Exp.pm 16 2006-11-04 23:39:16Z Julian Mehnle $
+# $Id: Exp.pm 22 2006-11-15 03:31:28Z Julian Mehnle $
 #
 ##############################################################################
 
@@ -30,7 +30,7 @@ use constant TRUE   => (0 == 0);
 use constant FALSE  => not TRUE;
 
 use constant name           => 'exp';
-use constant name_pattern   => qr/${\name}/;
+use constant name_pattern   => qr/${\name}/i;
 
 =head1 DESCRIPTION
 
@@ -128,19 +128,20 @@ sub process {
     my ($self, $server, $request, $result) = @_;
     
     try {
-        my $exp_domain = $self->{domain_spec}->expand($server, $request);
+        my $exp_domain = $self->{domain_spec}->new(server => $server, request => $request);
         my $txt_packet = $server->dns_lookup($exp_domain, 'TXT');
         my @txt_rrs = grep($_->type eq 'TXT', $txt_packet->answer);
-        @txt_rrs >= 1
+        @txt_rrs > 0
             or throw Mail::SPF::Result::PermError($request,
                 "No explanation string available at domain '$exp_domain'");  # RFC 4408, 6.2/4
-        @txt_rrs <= 1
+        @txt_rrs == 1
             or throw Mail::SPF::Result::PermError($request,
                 "Redundant explanation strings found at domain '$exp_domain'");  # RFC 4408, 6.2/4
         my $explanation = Mail::SPF::MacroString->new(
-            text    => join('', $txt_rrs[0]->char_str_list),
-            server  => $server,
-            request => $request
+            text            => join('', $txt_rrs[0]->char_str_list),
+            server          => $server,
+            request         => $request,
+            is_explanation  => TRUE
         );
         $request->state('explanation', $explanation);
     }
@@ -159,7 +160,7 @@ See L<Mail::SPF::Mod> for other supported instance methods.
 
 L<Mail::SPF>, L<Mail::SPF::Mod>, L<Mail::SPF::Term>, L<Mail::SPF::Record>
 
-L<http://www.ietf.org/rfc/rfc4408.txt|"RFC 4408">
+L<RFC 4408|http://www.ietf.org/rfc/rfc4408.txt>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
