@@ -4,7 +4,7 @@
 #
 # (C) 2005-2006 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: Record.pm 16 2006-11-04 23:39:16Z Julian Mehnle $
+# $Id: Record.pm 22 2006-11-15 03:31:28Z Julian Mehnle $
 #
 ##############################################################################
 
@@ -49,7 +49,7 @@ use constant version_tag_pattern    => qr{
     /
     ( (?: mfrom | pra ) (?: , (?: mfrom | pra ) )* )
     (?= \x20 | $ )
-}x;
+}ix;
 
 =head1 SYNOPSIS
 
@@ -96,8 +96,10 @@ sub new {
     my ($self, %options) = @_;
     $self = $self->SUPER::new(%options);
     
-    if (defined(my $scopes = $self->{scopes})) {
-        ref($scopes) eq 'ARRAY' and @$scopes > 0
+    if (not defined($self->{parse_text})) {
+        # No parsing is intended, so scopes should have been specified:
+        my $scopes = $self->{scopes} || [];
+        @$scopes > 0
             or throw Mail::SPF::EInvalidScope('No scopes for spf2.0 record');
         foreach my $scope (@$scopes) {
             $scope =~ $self->valid_scope
@@ -153,7 +155,13 @@ The following instance methods are provided:
 sub parse_version_tag {
     my ($self) = @_;
     if ($self->{parse_text} =~ s/^${\$self->version_tag_pattern}(?:\x20+|$)//) {
-        $self->{scopes} = [ split(/,/, $2) ];
+        my $scopes = $self->{scopes} = [ split(/,/, $2) ];
+        @$scopes > 0
+            or throw Mail::SPF::EInvalidScope('No scopes for spf2.0 record');
+        foreach my $scope (@$scopes) {
+            $scope =~ $self->valid_scope
+                or throw Mail::SPF::EInvalidScope("Invalid scope '$scope' for spf2.0 record");
+        }
     }
     else {
         throw Mail::SPF::EInvalidRecordVersion(
@@ -201,7 +209,7 @@ sub version_tag {
 L<Mail::SPF>, L<Mail::SPF::Record>, L<Mail::SPF::Term>, L<Mail::SPF::Mech>,
 L<Mail::SPF::Mod>
 
-L<http://www.ietf.org/rfc/rfc4408.txt|"RFC 4408">
+L<RFC 4408|http://www.ietf.org/rfc/rfc4408.txt>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
